@@ -1,8 +1,8 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2002 CodeFactory AB
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
- * Copyright (C) 2005-2006 Imendio AB
+ * Copyright (C) 2005-2008 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,13 +23,12 @@
 #ifndef __DH_BASE_H__
 #define __DH_BASE_H__
 
-#include <glib-object.h>
-#include <gtk/gtkwidget.h>
-#include <gconf/gconf-client.h>
+#include <gtk/gtk.h>
+
+G_BEGIN_DECLS
 
 typedef struct _DhBase      DhBase;
 typedef struct _DhBaseClass DhBaseClass;
-typedef struct _DhBasePriv  DhBasePriv;
 
 #define DH_TYPE_BASE         (dh_base_get_type ())
 #define DH_BASE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), DH_TYPE_BASE, DhBase))
@@ -38,11 +37,8 @@ typedef struct _DhBasePriv  DhBasePriv;
 #define DH_IS_BASE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), DH_TYPE_BASE))
 #define DH_BASE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), DH_TYPE_BASE, DhBaseClass))
 
-
 struct _DhBase {
-        GObject     parent;
-        
-        DhBasePriv *priv;
+        GObject parent_instance;
 };
 
 struct _DhBaseClass {
@@ -53,10 +49,12 @@ GType        dh_base_get_type                        (void) G_GNUC_CONST;
 DhBase *     dh_base_get                             (void);
 DhBase *     dh_base_new                             (void);
 GtkWidget *  dh_base_new_window                      (DhBase *base);
+GtkWidget *  dh_base_new_assistant                   (DhBase *base);
+GtkWidget *  dh_base_get_window                      (DhBase *base);
 GtkWidget *  dh_base_get_window_on_current_workspace (DhBase *base);
 GNode *      dh_base_get_book_tree                   (DhBase *base);
 GList *      dh_base_get_keywords                    (DhBase *base);
-GSList *     dh_base_get_windows                     (DhBase *base);
-GConfClient *dh_base_get_gconf_client                (DhBase *base);
+
+G_END_DECLS
 
 #endif /* __DH_BASE_H__ */
